DynClone

Trait DynClone 

pub unsafe trait DynClone: DynCloneSealed { }
A bound for the LateStruct::EraseTo associated type which asserts that fields must have an implementation of Clone. If LateStruct::EraseTo implements this trait, the LateInstance instantiating that structure will implement Clone.

This trait is implemented for all types which implement Clone. Unlike Clone, however, it is dyn compatible.

Safety

This trait is sealed and no downstream crates can implement it.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: Clone> DynClone for T