pub trait DynEq: DynPartialEq + DynEqSealed { }Expand description
A bound for the LateStruct::EraseTo associated type which asserts that fields must have an
implementation of Eq against itself. If LateStruct::EraseTo implements this trait, the
LateInstance instantiating that structure will implement Eq.
This trait is implemented for all types which implement Eq<Self>. Unlike Eq<Self>, however,
it is dyn compatible.
This trait is sealed and no downstream crates can implement it.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".